<!DOCTYPE TS><TS>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation>Åben</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <source>error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file.</source>
        <translation>Det var ikke muligt at skrive til den ønskede fil.</translation>
    </message>
</context>
<context>
    <name>CFormDef</name>
    <message>
        <source>Sail corners coordinates</source>
        <translation>Sejllhjørne koordinator</translation>
    </message>
    <message>
        <source>tack</source>
        <translation>halsbarm</translation>
    </message>
    <message>
        <source>clew</source>
        <translation>klampe</translation>
    </message>
    <message>
        <source>head</source>
        <translation>hoved</translation>
    </message>
    <message>
        <source>peak</source>
        <translation>top</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation>IRC med målinger</translation>
    </message>
</context>
<context>
    <name>CFormDefBase</name>
    <message>
        <source>Sail definition</source>
        <translation>Sejl defination</translation>
    </message>
    <message>
        <source>Sail shape</source>
        <translation>Sejl form</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Top depth</source>
        <translation>Top dybde</translation>
    </message>
    <message>
        <source>Mid depth</source>
        <translation>Mellem dybde</translation>
    </message>
    <message>
        <source>Foot depth</source>
        <translation>Sejlfod dybde</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Tvist vinkel</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Lag vinkel</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>grd</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Sejl dimension</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <source>Round position</source>
        <translation>Rundings position</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Forli længde</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Sejlfod længde</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Bagli længde</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Gaffel længde</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Bagli runding</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Forli runding</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Fodrunding</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Gaffel runding</translation>
    </message>
    <message>
        <source>Gaff angle from luff</source>
        <translation>Gaffel vinkel fra forli</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonal</translation>
    </message>
    <message>
        <source>Sail area</source>
        <translation>Sejl areal</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m² </translation>
    </message>
    <message>
        <source>Compute</source>
        <translation>Beregn</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <source>Mitre cut</source>
        <translation>Mitre cut</translation>
    </message>
    <message>
        <source>Cross cut</source>
        <translation>Cross cut</translation>
    </message>
    <message>
        <source>Twist foot</source>
        <translation>Vridning ved fod</translation>
    </message>
    <message>
        <source>Horizontal cut</source>
        <translation>Horisontal cut</translation>
    </message>
    <message>
        <source>Vertical cut</source>
        <translation>Vertikal cut</translation>
    </message>
    <message>
        <source>Number of luff gores</source>
        <translation>Antal af forli kiler</translation>
    </message>
    <message>
        <source>Number of radial gores</source>
        <translation>Antal af radiale kiler</translation>
    </message>
    <message>
        <source>Number of sections</source>
        <translation>Antal af sektioner</translation>
    </message>
    <message>
        <source>Radial cut</source>
        <translation>Radial Cut</translation>
    </message>
    <message>
        <source>Cloth</source>
        <translation>Tekstil</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Tekstil bredde</translation>
    </message>
    <message>
        <source>Leech hem</source>
        <translation>Bagli kantning</translation>
    </message>
    <message>
        <source>Other hems</source>
        <translation>Andre kantning</translation>
    </message>
    <message>
        <source>Seam width</source>
        <translation>Søm bredde</translation>
    </message>
    <message>
        <source>Rig geometry</source>
        <translation>Rig geometri</translation>
    </message>
    <message>
        <source>Fore triangle hoist  I</source>
        <translation>Forstags længde L mål</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation>Mast/forli hældning</translation>
    </message>
    <message>
        <source>Fore triangle base  J</source>
        <translation>Afstand fra forstævn til mast, J mål</translation>
    </message>
    <message>
        <source>Distance tack to stem</source>
        <translation>Afstand fra halsbarm til for
stævn</translation>
    </message>
    <message>
        <source>Tack height</source>
        <translation>Halsbarm højde</translation>
    </message>
    <message>
        <source>Boat length LOA</source>
        <translation>Bådlængde LOA</translation>
    </message>
    <message>
        <source>Sail ID</source>
        <translation>Sejl ID</translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation>Storsejl</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fok</translation>
    </message>
    <message>
        <source>Dihedral angle</source>
        <translation>Toplansvinkel</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Vinge</translation>
    </message>
    <message>
        <source>Sail identifier</source>
        <translation>Sejl identifikation</translation>
    </message>
    <message>
        <source>m2</source>
        <translation>m2</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <source>Sailcut CAD Handbook</source>
        <translation>Sailcut CAD håndbog</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Åben</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Åben &amp;seneste</translation>
    </message>
    <message>
        <source>data</source>
        <translation>data</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation>tegning</translation>
    </message>
    <message>
        <source>develop</source>
        <translation type="obsolete">design</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Udskriv</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Gem</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Gem &amp;Som</translation>
    </message>
    <message>
        <source>to &amp;DXF</source>
        <translation>til &amp;DXF format</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation>til &amp;TXT format</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation>til &amp;XML format</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation>E&amp;ksporter 3D sejl</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation>til C&amp;arlson plotter</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation>Eksporter &amp;design sæt</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensionering</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation>&amp;Form</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation>&amp;Hjørnelapper</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation>&amp;Rig</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprog</translation>
    </message>
    <message>
        <source>Sailcut CAD &amp;Handbook</source>
        <translation>Sailcut CAD &amp;Håndbog</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Sailcut CAD</source>
        <translation>Om &amp;Sailcut CAD</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vælg</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation>3D visning</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation>Trådramme visning</translation>
    </message>
    <message>
        <source>development</source>
        <translation>Design sæt</translation>
    </message>
    <message>
        <source>loaded &apos;%1&apos;</source>
        <translation>Åbnet &apos;%1&apos;</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation>udviklet nyt sejl</translation>
    </message>
    <message>
        <source>About Sailcut CAD</source>
        <translation>Om Sailcut CAD</translation>
    </message>
    <message>
        <source>error loading &apos;%1&apos;</source>
        <translation>Fejl i åbning &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="obsolete">Sejl type</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="obsolete">Storsejl</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="obsolete">Fok</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="obsolete">Sejl layout</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="obsolete">Cross Cut</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Horisontal Cut</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="obsolete">Radial Cut</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Twistet Foot Cut</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="obsolete">Vertikal Cut</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="obsolete">Mitre Cut</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation type="obsolete">sektioner</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation type="obsolete">hoved kiler</translation>
    </message>
    <message>
        <source> luff gore.</source>
        <translation type="obsolete">forli kiler.</translation>
    </message>
    <message>
        <source>Rig </source>
        <translation type="obsolete">Rig</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="obsolete">Bådens LOA</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Forstags længde I mål</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Afstand fra forstævn til mast, J mål</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="obsolete">Halsbarm position X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="obsolete">Halsbarm højde Y</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="obsolete">Sejl dimensioner</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="obsolete">Forli længde</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Maste/Forli hældning</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Gaffel vinkel fra forli</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="obsolete">Gaffel længde</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="obsolete">Sejlfod længde</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="obsolete">Bagli længde</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation type="obsolete">Kanternes form</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="obsolete">Forli runding</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="obsolete">Gaffel runding</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="obsolete">Bagli runding</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="obsolete">Sejlfod runding</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="obsolete">Forli rundings position</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="obsolete">Position af Gaffel runding</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="obsolete">Bagli rundings position</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="obsolete">Sejlfods rundings position</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="obsolete">Sejl egenskaber</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="obsolete">Tvist vinkel</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="obsolete">Lag vinkel</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Sømme og kantninger</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="obsolete">Tekstil bredde</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="obsolete">Sømbredde</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="obsolete">Bredde på bagli søm</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="obsolete">Andre søm bredde</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="obsolete">Sejl form</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="obsolete">Forli faktor</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="obsolete">Dybde</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="obsolete">Bagli faktor</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="obsolete">Øverste profil</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Midter profil ved h =</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="obsolete">Nederste profil</translation>
    </message>
    <message>
        <source>error</source>
        <translation>fejl</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation>Der var fejl ved udskrivning af data</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation>Der var fejl ved udskrivning af design sæt</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation>Der var fejl ved udskrivning af tegning</translation>
    </message>
    <message>
        <source>wrote &apos;%1&apos;</source>
        <translation>skrevet &apos;%1&apos;</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Det var ikke muligt at skrive til den valgte fil</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="obsolete">Vinge</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation type="obsolete">forli kiler.</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="obsolete">grd</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation>&amp;Håndplotting format</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <source>Top profile</source>
        <translation>Øverste profil</translation>
    </message>
    <message>
        <source>Middle profile</source>
        <translation>Mellemste profil</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Nederste profil</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Sejl form</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuller</translation>
    </message>
    <message>
        <source>Vertical repartition</source>
        <translation>Vertikal omopdeling</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation>Rig</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation>sejl &amp;defination</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation>3D &amp;sejl</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation>&amp;Tilføj sejl</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Åbne</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Åbne &amp;seneste</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Gem</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Gem &amp;Som</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Det var ikke muligt at skrive til den ønskede fil</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation>Sejl information</translation>
    </message>
    <message>
        <source>file</source>
        <translation>fil</translation>
    </message>
    <message>
        <source>name</source>
        <translation>navn</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Genindlæs</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Opdater</translation>
    </message>
    <message>
        <source>error</source>
        <translation>fejl</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Det var ikke muligt at læse den ønskede fil.</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">Dette system understøtter ikke OpenGL.</translation>
    </message>
</context>
<context>
    <name>CSailPrinter</name>
    <message>
        <source>Sailcut CAD data sheet</source>
        <translation>Sailcut CAD data side</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation>Storsejl</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fok</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Vinge</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>grd</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation>Sejl type</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation>Cross Cut</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation>Horisontal Cut</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation>Radial Cut</translation>
    </message>
    <message>
        <source>sections</source>
        <translation>sektioner</translation>
    </message>
    <message>
        <source>head gores</source>
        <translation>hoved kiler</translation>
    </message>
    <message>
        <source>luff gores</source>
        <translation>forli kiler</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation>Twistet Foot Cut</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation>Vertikal Cut</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation>Mitre Cut</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation>Sejl layout</translation>
    </message>
    <message>
        <source>Rig</source>
        <translation>Rig</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation>Bådens LOA</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation>Maste/Forli hældning</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation>Halsbarm position X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation>Halsbarm højde Y</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation>Forstags længde I mål</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation>Afstand fra forstævn til mast, J mål</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Sejl dimension</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Forli længde</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Sejlfod længde</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Bagli længde</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Gaffel længde</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation>Gaffel vinkel fra forli</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation>Kanternes form</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Forli runding</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation>Forli rundings position</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Fodrunding</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation>Sejlfods rundings position</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Bagli runding</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation>Bagli rundings position</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Gaffel runding</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation>Position af Gaffel runding</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation>Sejl egenskaber</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Tvist vinkel</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Lag vinkel</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation>Sømme og kantninger</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Tekstil bredde</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation>Sømbredde</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation>Bredde på bagli søm</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation>Andre søm bredde</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Sejl form</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation>Forli faktor</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Dybde</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation>Bagli faktor</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Øverste profil</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation>Midter profil ved h =</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Nederste profil</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <source>Display parameters</source>
        <translation>Vis parameter</translation>
    </message>
    <message>
        <source>elevation</source>
        <translation>højde</translation>
    </message>
    <message>
        <source>azimuth</source>
        <translation>azimut</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>Reset view</source>
        <translation>Nulstil visning</translation>
    </message>
    <message>
        <source>Labeling</source>
        <translation>Bane nummerering</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Forstør</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Formindsk</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>grd</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <source>Luff shape</source>
        <translation>Forli form</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Dybde</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Leech shape</source>
        <translation>Bagli form</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>grader</translation>
    </message>
    <message>
        <source>cord</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation>fejl</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Det var ikke muligt at læse den ønskede fil.</translation>
    </message>
</context>
</TS>
